Contributing
============

When contributing to this repository, please first discuss the change you wish to make via issue,
email, or any other method with the owners of this repository before making a change.

Please note we have a code of conduct, please follow it in all your interactions with the project.

Submitting Changes
------------------

- Always make a new branch for your work.
- Patches should be small to facilitate easier review. Sometimes this will result in many small
  PRs to land a single large feature.
- Larger changes should be discussed in the project's GitHub issues page.
- New features and significant bug fixes should be documented in the changelog.
- You must have legal permission to distribute any code you contribute to ``vivarium``, and it
  must be available under both the GNU GPLv3 license.

